==> haskell-pcre-heavy-1.0.0.2-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-heavy
version: 1.0.0.2
id: pcre-heavy-1.0.0.2-A8ZsTnkJ8auKqFzUEYZdBv
key: pcre-heavy-1.0.0.2-A8ZsTnkJ8auKqFzUEYZdBv
license: PublicDomain
copyright: 2015 Greg V <greg@unrelenting.technology>
maintainer: greg@unrelenting.technology
homepage: https://github.com/myfreeweb/pcre-heavy
synopsis: A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!
category: Web
author: Greg V
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.PCRE.Heavy
abi: bafcd36134b70a1982c582d00b20c17d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pcre-heavy-1.0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/pcre-heavy-1.0.0.2
hs-libraries: HSpcre-heavy-1.0.0.2-A8ZsTnkJ8auKqFzUEYZdBv
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    pcre-light-0.4.0.4-1B7RAeH6a1p32rU9NBGpc1 bytestring-0.10.8.2
    string-conversions-0.4.0.1-4Kf1c6q8qP6CakUZjJ2l4Y
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             pcre-light-0.4.0.4-1B7RAeH6a1p32rU9NBGpc1=02175b483579f9801622dffc15004f68
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             string-conversions-0.4.0.1-4Kf1c6q8qP6CakUZjJ2l4Y=f32cb89438e7d323276302a8442d1d9b
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html: /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-heavy-1.0.0.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-heavy
version: 1.0.0.2
id: pcre-heavy-1.0.0.2-DaAp79JO7aqIdnQY5VRLXj
key: pcre-heavy-1.0.0.2-DaAp79JO7aqIdnQY5VRLXj
license: PublicDomain
copyright: 2015 Greg V <greg@unrelenting.technology>
maintainer: greg@unrelenting.technology
homepage: https://github.com/myfreeweb/pcre-heavy
synopsis: A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!
category: Web
author: Greg V
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.PCRE.Heavy
abi: 6d3f8965f0c268e4308ce8502537b56e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pcre-heavy-1.0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/pcre-heavy-1.0.0.2
hs-libraries: HSpcre-heavy-1.0.0.2-DaAp79JO7aqIdnQY5VRLXj
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    pcre-light-0.4.0.4-1B7RAeH6a1p32rU9NBGpc1 bytestring-0.10.8.2
    string-conversions-0.4.0.1-4Kf1c6q8qP6CakUZjJ2l4Y
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             pcre-light-0.4.0.4-1B7RAeH6a1p32rU9NBGpc1=02175b483579f9801622dffc15004f68
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             string-conversions-0.4.0.1-4Kf1c6q8qP6CakUZjJ2l4Y=f32cb89438e7d323276302a8442d1d9b
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html: /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
